abacusai.organization_search_result — AbacusAI documentation

# `abacusai.organization_search_result`

## Module Contents

### Classes

`OrganizationSearchResult` | A search result object which contains the retrieved artifact and its relevance score

class abacusai.organization_search_result.OrganizationSearchResult(client, score=None, featureGroup={}, featureGroupVersion={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A search result object which contains the retrieved artifact and its relevance score

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - score (float) – The relevance score of the search result.

    - featureGroup (FeatureGroup) – The feature group object retrieved through search.

    - featureGroupVersion (FeatureGroupVersion) – The feature group version object retrieved through search.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict